/*
 * Extreme Mac OS X Programming
 *
 * Using Google Web APIs in a Mac OS X Application
 * http://javworld.com/extreme/GoogleAPI.html
 *
 * Copyright  2004 John A. Vink
 *
 */


#import "GoogleXMLController.h"

#import "WSStub.h"

@implementation GoogleXMLController

// -----------------------------------------------------------------------
// * awakeFromNib
// -----------------------------------------------------------------------
- (void) awakeFromNib
{
	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(newSelection:) name:NSTableViewSelectionDidChangeNotification object:resultsTable];
}


// -----------------------------------------------------------------------
// * doSearch
// -----------------------------------------------------------------------
- (IBAction)doSearch:(id)sender
{
		// get the query
	NSString* query = [searchField stringValue];
	
		// get the Google Developer API key.  Dont' use mine, get your own.
	NSString* googleKey = [googleDevKeyField stringValue];
	
		// make me one of them WSGeneratedObj just for making the search API call.
		// doGoogleSearch is declared in WSStub.h, and is a subclass of WSGeneratedObj.
	doGoogleSearch* doSearch = [[doGoogleSearch alloc] init];
	
		// now feed it a bunch of parameters.
	[doSearch setParameters:googleKey
				in_q:query
				in_start:1
				in_maxResults:10
				in_filter:YES
				in_restrict:@""
				in_safeSearch:NO
				in_lr:@"lang_en"
				in_ie:@""
				in_oe:@""];
		
		// this performs the actual remote procedure call
	NSDictionary* result = [doSearch resultValue];
	
		// put the exact result in the UI so geeks can read it
	[resultField insertText:[[doSearch getResultDictionary] description]];
	
		// we're done with this thing
	[doSearch release];
	
		// retain the search results so we can populate UI here and there
	[searchResults release];
	searchResults = [[result objectForKey:@"resultElements"] retain];
	
		// tell our table we have new results
	[resultsTable reloadData];
}


// -----------------------------------------------------------------------
// * numberOfRowsInTableView
// -----------------------------------------------------------------------
- (int)numberOfRowsInTableView:(NSTableView *)tableView
{
	return [searchResults count];
}


// -----------------------------------------------------------------------
// * objectValueForTableColumn
// -----------------------------------------------------------------------
- (id)tableView:(NSTableView *)tableView objectValueForTableColumn:(NSTableColumn *)tableColumn row:(int)row
{
	return [[searchResults objectAtIndex:row] objectForKey:@"title"];
}


// -----------------------------------------------------------------------
// * newSelection
// -----------------------------------------------------------------------
- (void) newSelection:(NSNotification*)note
{
	int selection = [resultsTable selectedRow];
	if (selection != -1)
	{
		[summaryField setString:[[searchResults objectAtIndex:selection] objectForKey:@"snippet"]];
	}
}


// -----------------------------------------------------------------------
// * applicationShouldTerminateAfterLastWindowClosed
// -----------------------------------------------------------------------
// Causes the application to quit when the one and only window is closed
- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)sender
{
	return YES;
}


// -----------------------------------------------------------------------
// * getDevKey
// -----------------------------------------------------------------------
- (IBAction) getDevKey:(id)sender
{
	CFURLRef devKeyURL = CFURLCreateWithString(nil, CFSTR("http://www.google.com/apis/"), nil);
	LSOpenCFURLRef(devKeyURL, nil);
}

@end
